@@ -173,21 +173,21 @@ libanjuta_iface_cclosure_marshal_VOID__INT_CHAR (GClosure     *closure,
 
 /* VOID:STRING (./libanjuta-iface-marshallers.list:7) */
 
-/* VOID:STRING,UINT,STRING (./libanjuta-iface-marshallers.list:8) */
+/* VOID:STRING,UINT,UINT (./libanjuta-iface-marshallers.list:8) */
 void
-libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_STRING (GClosure     *closure,
-                                                           GValue       *return_value,
-                                                           guint         n_param_values,
-                                                           const GValue *param_values,
-                                                           gpointer      invocation_hint,
-                                                           gpointer      marshal_data)
+libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_UINT (GClosure     *closure,
+                                                         GValue       *return_value,
+                                                         guint         n_param_values,
+                                                         const GValue *param_values,
+                                                         gpointer      invocation_hint,
+                                                         gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__STRING_UINT_STRING) (gpointer     data1,
-                                                         gpointer     arg_1,
-                                                         guint        arg_2,
-                                                         gpointer     arg_3,
-                                                         gpointer     data2);
-  register GMarshalFunc_VOID__STRING_UINT_STRING callback;
+  typedef void (*GMarshalFunc_VOID__STRING_UINT_UINT) (gpointer     data1,
+                                                       gpointer     arg_1,
+                                                       guint        arg_2,
+                                                       guint        arg_3,
+                                                       gpointer     data2);
+  register GMarshalFunc_VOID__STRING_UINT_UINT callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
@@ -203,12 +203,12 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_UINT_STRING (GClosure     *closure
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__STRING_UINT_STRING) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__STRING_UINT_UINT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
             g_marshal_value_peek_string (param_values + 1),
             g_marshal_value_peek_uint (param_values + 2),
-            g_marshal_value_peek_string (param_values + 3),
+            g_marshal_value_peek_uint (param_values + 3),
             data2);
 }
 
