@@ -62,8 +62,8 @@
 #include "utilities.h"
 
 /* Markers definition */
-#define BREAKPOINT_ENABLED   IANJUTA_MARKABLE_INTENSE
-#define BREAKPOINT_DISABLED  IANJUTA_MARKABLE_ATTENTIVE
+#define BREAKPOINT_ENABLED   IANJUTA_MARKABLE_BREAKPOINT_ENABLED
+#define BREAKPOINT_DISABLED  IANJUTA_MARKABLE_BREAKPOINT_DISABLED
 #define BREAKPOINT_NONE      -1
 
 typedef struct _BreakpointItem BreakpointItem;
