@@ -24,11 +24,10 @@
 
 #include <config.h>
 
-//#define DEBUG
+/*#define DEBUG*/
 
 #include "debugger.h"
 
-#include <libanjuta/plugins.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
 #include <libanjuta/interfaces/ianjuta-variable-debugger.h>
@@ -306,10 +305,10 @@ typedef struct _DmaQueueCommand
 			gchar *file;
 			gchar *type;
 			GList *dirs;
+			gboolean terminal;
 		} load;
 		struct {
 			gchar *args;
-			gboolean terminal;
 		} start;
 		struct {
 			pid_t pid;
@@ -841,11 +840,34 @@ dma_queue_update_queue_status (DmaDebuggerQueue *this, DmaDebuggerCommandType ty
 	}
 }
 
+static void
+dma_queue_emit_debugger_ready (DmaDebuggerQueue *queue)
+{
+	IAnjutaDebuggerStatus stat;
+	static gboolean busy = FALSE;
+	
+	if ((queue->head == NULL) && (queue->ready))
+	{
+		stat = queue->queue_status;
+		busy = FALSE;
+	}
+	else if (busy)
+	{
+		/* Busy signal already emitted, do nothing */
+		return;
+	}
+	else
+	{
+		stat = IANJUTA_DEBUGGER_BUSY;
+		busy = TRUE;
+	}
+	
+	g_signal_emit_by_name (queue, "debugger-ready", stat);
+}
+
 void
 dma_queue_update_debugger_status (DmaDebuggerQueue *this, IAnjutaDebuggerStatus status)
 {
-	// DmaQueueCommand *head;
-	// DmaQueueCommand *tail;
 	const char* signal = NULL;
 
 	this->queue_command = FALSE;
@@ -1090,7 +1112,7 @@ dma_debugger_queue_execute (DmaDebuggerQueue *this)
 	 	    ianjuta_debugger_initialize (this->debugger, on_debugger_output, this, &err);
 		    break;
 		case LOAD_COMMAND:
-			ianjuta_debugger_load (this->debugger, cmd->load.file, cmd->load.type, cmd->load.dirs, &err);	
+			ianjuta_debugger_load (this->debugger, cmd->load.file, cmd->load.type, cmd->load.dirs, cmd->load.terminal, &err);	
 			break;
   	    case ATTACH_COMMAND:
 			ianjuta_debugger_attach (this->debugger, cmd->attach.pid, cmd->load.dirs, &err);	
@@ -1107,7 +1129,7 @@ dma_debugger_queue_execute (DmaDebuggerQueue *this)
 			ianjuta_debugger_abort (this->debugger, &err);
 			break;
 		case START_COMMAND:
-			ianjuta_debugger_start (this->debugger, cmd->start.args, cmd->start.terminal, &err);
+			ianjuta_debugger_start (this->debugger, cmd->start.args, &err);
 		    break;
 		case RUN_COMMAND:
 			ianjuta_debugger_run (this->debugger, &err);	
@@ -1203,7 +1225,7 @@ dma_debugger_queue_execute (DmaDebuggerQueue *this)
 			ianjuta_cpu_debugger_inspect_memory (this->cpu_debugger, cmd->mem.address, cmd->mem.length, cmd->callback, cmd->user_data, &err);	
 			break;
 		case DISASSEMBLE_COMMAND:
-			ianjuta_cpu_debugger_disassemble (this->debugger, cmd->mem.address, cmd->mem.length, cmd->callback, cmd->user_data, &err);	
+			ianjuta_cpu_debugger_disassemble (this->cpu_debugger, cmd->mem.address, cmd->mem.length, cmd->callback, cmd->user_data, &err);	
 			break;
 		case BREAK_LINE_COMMAND:
 			ianjuta_debugger_set_breakpoint_at_line (this->debugger, cmd->pos.file, cmd->pos.line, cmd->callback, cmd->user_data, &err);	
@@ -1271,6 +1293,7 @@ dma_debugger_queue_execute (DmaDebuggerQueue *this)
 			g_error_free (err);
 		}
 	}
+	dma_queue_emit_debugger_ready (this);
 }
 
 /* Public message functions
@@ -1358,7 +1381,7 @@ on_dma_program_exited (DmaDebuggerQueue *this)
 }
 
 static void
-on_dma_location_changed (DmaDebuggerQueue *this, const gchar* src_path, guint line, const gchar* address)
+on_dma_location_changed (DmaDebuggerQueue *this, const gchar* src_path, guint line, guint address)
 {
 	DEBUG_PRINT ("From debugger: location changed");
 	g_signal_emit_by_name (this, "location-changed", src_path, line, address);
@@ -1410,7 +1433,7 @@ idebugger_initialize (IAnjutaDebugger *iface, IAnjutaDebuggerOutputCallback call
 
 static gboolean
 idebugger_load (IAnjutaDebugger *iface, const gchar *file, const gchar* mime_type,
-				const GList *search_dirs, GError **err)
+				const GList *search_dirs, gboolean terminal, GError **err)
 {
 	DmaDebuggerQueue *this = DMA_DEBUGGER_QUEUE (iface);
 	DmaQueueCommand *cmd;
@@ -1422,6 +1445,7 @@ idebugger_load (IAnjutaDebugger *iface, const gchar *file, const gchar* mime_typ
 	cmd->load.file = g_strdup (file);
 	cmd->load.type = g_strdup (mime_type);
 	cmd->load.dirs = NULL;
+	cmd->load.terminal = terminal;
 	for (node = search_dirs; node != NULL; node = g_list_next (node))
 	{
 		cmd->load.dirs = g_list_prepend (cmd->load.dirs, g_strdup (node->data));
@@ -1457,7 +1481,7 @@ idebugger_attach (IAnjutaDebugger *iface, pid_t pid, const GList *search_dirs, G
 }
 
 static gboolean
-idebugger_start (IAnjutaDebugger *iface, const gchar *args, gboolean terminal, GError **err)
+idebugger_start (IAnjutaDebugger *iface, const gchar *args, GError **err)
 {
 	DmaDebuggerQueue *this = DMA_DEBUGGER_QUEUE (iface);
 	DmaQueueCommand *cmd;
@@ -1466,7 +1490,6 @@ idebugger_start (IAnjutaDebugger *iface, const gchar *args, gboolean terminal, G
 	if (cmd == NULL) return FALSE;
 		
 	cmd->start.args = args == NULL ? NULL : g_strdup (args);
-	cmd->start.terminal = terminal;
 	dma_debugger_queue_execute (this);
 	
 	return TRUE;
@@ -2207,7 +2230,7 @@ icpu_debugger_inspect_memory (IAnjutaCpuDebugger *iface, guint address, guint le
 }
 
 static gboolean
-icpu_debugger_disassemble (IAnjutaDebugger *iface, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
+icpu_debugger_disassemble (IAnjutaCpuDebugger *iface, guint address, guint length, IAnjutaDebuggerCallback callback , gpointer user_data, GError **err)
 {
 	DmaDebuggerQueue *this = (DmaDebuggerQueue *)iface;
 	DmaQueueCommand *cmd;
