@@ -20,7 +20,7 @@
 
 #include <config.h>
 
-//#define DEBUG
+/*#define DEBUG*/
 
 #include "plugin.h"
 
@@ -40,10 +40,11 @@
 
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
-#include <libanjuta/plugins.h>
+#include <libanjuta/anjuta-status.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-indicable.h>
+#include <libanjuta/interfaces/ianjuta-markable.h>
 #include <libanjuta/interfaces/ianjuta-debug-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
@@ -61,15 +62,6 @@
 /* Plugin type
  *---------------------------------------------------------------------------*/
 
-typedef enum _DebugManagerState
-{
-	DMA_DEBUGGER_STOPPED,
-	DMA_DEBUGGER_STARTED,
-	DMA_PROGRAM_LOADED,
-	DMA_PROGRAM_BROKEN,
-	DMA_PROGRAM_RUNNING
-} DebugManagerState;
-
 struct _DebugManagerPlugin
 {
 	AnjutaPlugin parent;
@@ -92,6 +84,9 @@ struct _DebugManagerPlugin
 	/* Editor */
 	IAnjutaEditor *current_editor;
 	guint editor_watch_id;
+	IAnjutaEditor *pc_editor;
+	guint pc_line;
+	gboolean busy;
 	
 	/* Debugger components */
 	Locals *locals;
@@ -105,8 +100,6 @@ struct _DebugManagerPlugin
 	DmaMemory *memory;
 	DmaDisassemble *disassemble;
 	
-	/* Debugger status */
-	DebugManagerState state;
 	
 	/* Logging view */
 	IAnjutaMessageView* view;
@@ -154,6 +147,80 @@ register_stock_icons (AnjutaPlugin *plugin)
 		REGISTER_ICON ("run-to-cursor.png", "debugger-run-to-cursor");
 }
 
+/* Program counter functions
+ *---------------------------------------------------------------------------*/
+
+static void
+show_program_counter_in_editor(DebugManagerPlugin *self)
+{
+	IAnjutaEditor *editor = self->current_editor;
+	
+	if ((editor != NULL) && (self->pc_editor == editor))
+	{
+		if (IANJUTA_IS_MARKABLE (editor))
+		{
+			ianjuta_markable_mark(IANJUTA_MARKABLE (editor), self->pc_line, IANJUTA_MARKABLE_PROGRAM_COUNTER, NULL);
+		}
+		if (IANJUTA_IS_INDICABLE(editor))
+		{
+			gint begin = ianjuta_editor_get_line_begin_position(editor, self->pc_line, NULL);
+			gint end = ianjuta_editor_get_line_end_position(editor, self->pc_line, NULL);
+			
+			ianjuta_indicable_set(IANJUTA_INDICABLE(editor), begin, end, IANJUTA_INDICABLE_IMPORTANT,
+				NULL);
+		}		
+	}
+}
+
+static void
+hide_program_counter_in_editor(DebugManagerPlugin *self)
+{
+	IAnjutaEditor *editor = self->current_editor;
+	
+	if ((editor != NULL) && (self->pc_editor == editor))
+	{
+		if (IANJUTA_IS_MARKABLE (editor))
+		{
+			ianjuta_markable_delete_all_markers (IANJUTA_MARKABLE (editor), IANJUTA_MARKABLE_PROGRAM_COUNTER, NULL);
+		}
+		if (IANJUTA_IS_INDICABLE(editor))
+		{
+			ianjuta_indicable_clear(IANJUTA_INDICABLE(editor), NULL);			
+		}		
+	}
+}
+
+static void
+set_program_counter(DebugManagerPlugin *self, const gchar* file, guint line, guint address)
+{
+	IAnjutaDocumentManager *docman = NULL;
+	gchar *file_uri;
+
+	/* Remove previous marker */
+	hide_program_counter_in_editor (self);
+	self->pc_editor = NULL;
+
+	if (file != NULL)
+	{
+		docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (self)->shell, IAnjutaDocumentManager, NULL);
+		file_uri = g_strconcat ("file://", file, NULL);
+		if (docman)
+		{
+			IAnjutaEditor* editor;
+		
+			editor = ianjuta_document_manager_goto_file_line(docman, file_uri, line, NULL);
+		
+			if (editor != NULL)
+			{
+				self->pc_editor = editor;
+				self->pc_line = line;
+				show_program_counter_in_editor (self);
+			}
+		}		
+		g_free (file_uri);
+	}
+}
+
 static void
 value_added_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 							  const GValue *value, gpointer user_data)
@@ -192,27 +259,32 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 							const GValue *value, gpointer data)
 {
 	IAnjutaEditor *editor;
-	DebugManagerPlugin *dm_plugin;
+	DebugManagerPlugin *self;
 
 	editor = IANJUTA_EDITOR (g_value_get_object (value));
-	dm_plugin = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
-	dm_plugin->current_editor = editor;
+	self = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
+	self->current_editor = editor;
 	
     /* Restore breakpoints */
-	breakpoints_dbase_set_all_in_editor (dm_plugin->breakpoints, editor);
+	breakpoints_dbase_set_all_in_editor (self->breakpoints, editor);
 	
+	/* Restore program counter marker */
+	show_program_counter_in_editor (self);
 }
 
 static void
 value_removed_current_editor (AnjutaPlugin *plugin,
 							  const char *name, gpointer data)
 {
-	DebugManagerPlugin *dm_plugin = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
+	DebugManagerPlugin *self = ANJUTA_PLUGIN_DEBUG_MANAGER (plugin);
 
-	if (dm_plugin->current_editor)
-		breakpoints_dbase_clear_all_in_editor (dm_plugin->breakpoints,
-            dm_plugin->current_editor);
-	dm_plugin->current_editor = NULL;
+	if (self->current_editor)
+		breakpoints_dbase_clear_all_in_editor (self->breakpoints,
+            self->current_editor);
+	
+	hide_program_counter_in_editor (self);
+	
+	self->current_editor = NULL;
 }
 
 static void
@@ -272,6 +344,27 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 /* State functions
  *---------------------------------------------------------------------------*/
 
+static void
+dma_plugin_debugger_ready (DebugManagerPlugin *self, IAnjutaDebuggerStatus stat)
+{
+	AnjutaStatus* status;
+
+	if ((stat == IANJUTA_DEBUGGER_BUSY) != self->busy)
+	{
+		status = anjuta_shell_get_status(ANJUTA_PLUGIN (self)->shell, NULL);
+		if (!self->busy)
+		{
+			anjuta_status_busy_push (status);
+			self->busy = TRUE;
+		}
+		else
+		{
+			anjuta_status_busy_pop (status);
+			self->busy = FALSE;
+		}
+	}
+}
+
 /* Called when the debugger is started but no program is loaded */
 
 static void
@@ -279,6 +372,7 @@ dma_plugin_debugger_started (DebugManagerPlugin *this)
 {
 	AnjutaUI *ui;
 	GtkAction *action;
+	AnjutaStatus* status;
 
 	DEBUG_PRINT ("DMA: dma_plugin_debugger_started");
 	
@@ -293,6 +387,11 @@ dma_plugin_debugger_started (DebugManagerPlugin *this)
 	gtk_action_group_set_sensitive (this->stopped_group, FALSE);
 	gtk_action_group_set_visible (this->running_group, TRUE);
 	gtk_action_group_set_sensitive (this->running_group, FALSE);
+	
+	status = anjuta_shell_get_status(ANJUTA_PLUGIN (this)->shell, NULL);
+	anjuta_status_set_default (status, _("Debugger"), _("Started"));
+	
+	dma_plugin_debugger_ready (this, IANJUTA_DEBUGGER_STARTED);
 }
 
 /* Called when a program is loaded */
@@ -301,6 +400,7 @@ static void
 dma_plugin_program_loaded (DebugManagerPlugin *this)
 {
 	AnjutaUI *ui;
+	AnjutaStatus* status;
 
 	DEBUG_PRINT ("DMA: dma_plugin_program_loaded");
 	
@@ -325,6 +425,9 @@ dma_plugin_program_loaded (DebugManagerPlugin *this)
 	gtk_action_group_set_sensitive (this->loaded_group, TRUE);
 	gtk_action_group_set_sensitive (this->stopped_group, FALSE);
 	gtk_action_group_set_sensitive (this->running_group, FALSE);
+	
+	status = anjuta_shell_get_status(ANJUTA_PLUGIN (this)->shell, NULL);
+	anjuta_status_set_default (status, _("Debugger"), _("Loaded"));
 }
 
 /* Called when the program is running */
@@ -333,6 +436,7 @@ static void
 dma_plugin_program_running (DebugManagerPlugin *this)
 {
 	AnjutaUI *ui;
+	AnjutaStatus* status;
 
 	DEBUG_PRINT ("DMA: dma_plugin_program_running");
 	
@@ -341,6 +445,11 @@ dma_plugin_program_running (DebugManagerPlugin *this)
 	gtk_action_group_set_sensitive (this->loaded_group, TRUE);
 	gtk_action_group_set_sensitive (this->stopped_group, FALSE);
 	gtk_action_group_set_sensitive (this->running_group, TRUE);
+	
+	status = anjuta_shell_get_status(ANJUTA_PLUGIN (this)->shell, NULL);
+	anjuta_status_set_default (status, _("Debugger"), _("Running..."));
+
+	set_program_counter(this, NULL, 0, 0);
 }
 
 /* Called when the program is stopped */
@@ -349,6 +458,7 @@ static void
 dma_plugin_program_stopped (DebugManagerPlugin *this)
 {
 	AnjutaUI *ui;
+	AnjutaStatus* status;
 	
 	DEBUG_PRINT ("DMA: dma_plugin_program_broken");
 	
@@ -362,15 +472,17 @@ dma_plugin_program_stopped (DebugManagerPlugin *this)
 	gtk_action_group_set_sensitive (this->loaded_group, TRUE);
 	gtk_action_group_set_sensitive (this->stopped_group, TRUE);
 	gtk_action_group_set_sensitive (this->running_group, FALSE);
+
+	status = anjuta_shell_get_status(ANJUTA_PLUGIN (this)->shell, NULL);
+	anjuta_status_set_default (status, _("Debugger"), _("Stopped"));
 }
 
 /* Called when the program postion change */
 
 static void
-dma_plugin_location_changed (DebugManagerPlugin *this, const gchar* file, guint line, const gchar* address)
+dma_plugin_location_changed (DebugManagerPlugin *this, const gchar* file, guint line, guint address)
 {
-	IAnjutaDocumentManager *docman = NULL;
-	gchar *msg, *file_uri;
+	gchar *msg;
 
 	DEBUG_PRINT ("DMA: dma_plugin_location_changed %s %d", file, line);
 	
@@ -378,25 +490,7 @@ dma_plugin_location_changed (DebugManagerPlugin *this, const gchar* file, guint
 	dma_debugger_message (this->queue, msg);
 	g_free (msg);
 
-	docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (this)->shell, IAnjutaDocumentManager, NULL);
-	file_uri = g_strconcat ("file://", file, NULL);
-	if (docman)
-	{
-		IAnjutaEditor* editor;
-		ianjuta_document_manager_goto_file_line_mark (docman, file_uri, line, TRUE, NULL);
-		editor = ianjuta_document_manager_get_current_editor(docman, NULL);
-		if (editor && IANJUTA_IS_INDICABLE(editor))
-		{
-			gint begin = ianjuta_editor_get_line_begin_position(editor, line, NULL);
-			gint end = ianjuta_editor_get_line_end_position(editor, line, NULL);
-			
-			ianjuta_indicable_clear(IANJUTA_INDICABLE(editor), NULL);			
-
-			ianjuta_indicable_set(IANJUTA_INDICABLE(editor), begin, end, IANJUTA_INDICABLE_IMPORTANT,
-				NULL);
-		}
-	}		
-	g_free (file_uri);
+	set_program_counter (this, file, line, address);
 }
 
 /* Called when a program is unloaded */
@@ -404,6 +498,7 @@ static void
 dma_plugin_program_unload (DebugManagerPlugin *this)
 {
 	AnjutaUI *ui;
+	AnjutaStatus* status;
 
 	DEBUG_PRINT ("DMA: dma_plugin_program_unload");
 	
@@ -431,6 +526,9 @@ dma_plugin_program_unload (DebugManagerPlugin *this)
 	gtk_action_group_set_sensitive (this->stopped_group, FALSE);
 	gtk_action_group_set_visible (this->running_group, TRUE);
 	gtk_action_group_set_sensitive (this->running_group, FALSE);
+	
+	status = anjuta_shell_get_status(ANJUTA_PLUGIN (this)->shell, NULL);
+	anjuta_status_set_default (status, _("Debugger"), _("Unloaded"));
 }
 
 /* Called when the debugger is stopped */
@@ -440,6 +538,7 @@ dma_plugin_debugger_stopped (DebugManagerPlugin *this)
 {
 	AnjutaUI *ui;
 	GtkAction *action;
+	AnjutaStatus* status;
 
 	DEBUG_PRINT ("DMA: dma_plugin_debugger_stopped");
 
@@ -459,12 +558,14 @@ dma_plugin_debugger_stopped (DebugManagerPlugin *this)
 	gtk_action_group_set_sensitive (this->running_group, FALSE);
 
 	/* clear indicator */
-	if (this->current_editor && IANJUTA_IS_INDICABLE(this->current_editor))
-	{
-		ianjuta_indicable_clear(IANJUTA_INDICABLE(this->current_editor), NULL);
-	}
+	set_program_counter (this, NULL, 0, 0);
 	
 	enable_log_view (this, FALSE);
+	
+	status = anjuta_shell_get_status(ANJUTA_PLUGIN (this)->shell, NULL);
+	anjuta_status_set_default (status, _("Debugger"), NULL);
+	
+	dma_plugin_debugger_ready (this, IANJUTA_DEBUGGER_STOPPED);
 }
 
 /* Start/Stop menu functions
@@ -694,6 +795,12 @@ on_debugger_signals_activate (GtkAction * action, DebugManagerPlugin *plugin)
 	signals_show (plugin->signals);
 }
 
+static void
+on_debugger_ready_signal (IAnjutaDebugger* dbg, IAnjutaDebuggerStatus stat, DebugManagerPlugin *plugin)
+{
+	dma_plugin_debugger_ready (plugin, stat);
+}
+
 /* Actions table
  *---------------------------------------------------------------------------*/
 
@@ -995,6 +1102,7 @@ dma_plugin_activate (AnjutaPlugin* plugin)
 	g_signal_connect_swapped (this->debugger, "program-stopped", G_CALLBACK (dma_plugin_program_stopped), this);
 	g_signal_connect_swapped (this->debugger, "program-exited", G_CALLBACK (dma_plugin_program_loaded), this);
 	g_signal_connect_swapped (this->debugger, "location-changed", G_CALLBACK (dma_plugin_location_changed), this);
+	g_signal_connect (this->debugger, "debugger-ready", G_CALLBACK (on_debugger_ready_signal), this);
 
 	/* Watch expression */
 	this->watch = expr_watch_new (ANJUTA_PLUGIN (plugin), this->debugger);
@@ -1061,6 +1169,7 @@ dma_plugin_deactivate (AnjutaPlugin* plugin)
 	g_signal_handlers_disconnect_by_func (this->queue, G_CALLBACK (dma_plugin_program_running), this);
 	g_signal_handlers_disconnect_by_func (this->queue, G_CALLBACK (dma_plugin_program_stopped), this);
 	g_signal_handlers_disconnect_by_func (this->queue, G_CALLBACK (dma_plugin_location_changed), this);
+	g_signal_handlers_disconnect_by_func (this->queue, G_CALLBACK (on_debugger_ready_signal), this);
 	dma_debugger_queue_free (this->queue);
 	this->queue = NULL;
 
