@@ -71,13 +71,29 @@
 #include "aneditor.h"
 #include "text_editor_prefs.h"
 
-/* Marker 0 is defined for bookmarks */
+/* Order is important, as marker with the lowest number is drawn first */
 #define TEXT_EDITOR_BOOKMARK                0
-#define TEXT_EDITOR_LINEMARKER              1
-#define TEXT_EDITOR_BREAKPOINT_DISABLED     2
-#define TEXT_EDITOR_BREAKPOINT_ENABLED      3
+#define TEXT_EDITOR_BREAKPOINT_DISABLED     1
+#define TEXT_EDITOR_BREAKPOINT_ENABLED      2
+#define TEXT_EDITOR_PROGRAM_COUNTER         3
+#define TEXT_EDITOR_LINEMARKER              4
 
-#define MARKER_PROP_END 0xaaaaaa /* Do not define any color with this value */
+/* Include marker pixmaps */
+#include "bookmark.xpm"
+#include "breakpoint-disabled.xpm"
+#include "breakpoint-enabled.xpm"
+#include "program-counter.xpm"
+#include "linemarker.xpm"
+
+static gchar* marker_pixmap[] = 
+{
+	bookmark_xpm,
+	breakpoint_disabled_xpm,
+	breakpoint_enabled_xpm,
+	program_counter_xpm,
+	linemarker_xpm,
+	NULL
+};
 
 /* Editor language supports */
 static GList *supported_languages = NULL;
@@ -85,16 +101,6 @@ static GHashTable *supported_languages_name = NULL;
 static GHashTable *supported_languages_ext = NULL;
 static GHashTable *supported_languages_by_lexer = NULL;
 
-/* marker fore and back colors */
-static glong marker_prop[] = 
-{
-	SC_MARK_ROUNDRECT,      0x00007f, 0xffff80,	/* Bookmark */
-	SC_MARK_SHORTARROW,     0x00007f, 0x00ffff,	/* Line mark */
-	SC_MARK_CIRCLE,         0x00007f, 0xffffff,	/* Breakpoint mark (disabled) */
-	SC_MARK_CIRCLE,         0x00007f, 0xff80ff,	/* Breakpoint mark (enabled) */
-	MARKER_PROP_END,	                        /* end */
-};
-
 static void text_editor_finalize (GObject *obj);
 static void text_editor_dispose (GObject *obj);
 static void text_editor_hilite_one (TextEditor * te, AnEditorID editor,
@@ -154,20 +160,15 @@ check_tm_file(TextEditor *te)
 static void
 initialize_markers (TextEditor* te, GtkWidget *scintilla)
 {
-	gint i, marker;
+	gint marker;
+	gchar **xpm;
 	g_return_if_fail (te != NULL);
 	
 	marker = 0;
-	for (i = 0;; i += 3)
+	for (xpm = marker_pixmap;*xpm != NULL; xpm++)
 	{
-		if (marker_prop[i] == MARKER_PROP_END)
-			break;
-		scintilla_send_message (SCINTILLA (scintilla), SCI_MARKERDEFINE,
-			marker, marker_prop[i+0]);
-		scintilla_send_message (SCINTILLA (scintilla), SCI_MARKERSETFORE,
-			marker, marker_prop[i+1]);
-		scintilla_send_message (SCINTILLA (scintilla), SCI_MARKERSETBACK,
-			marker, marker_prop[i+2]);
+		scintilla_send_message (SCINTILLA (scintilla), SCI_MARKERDEFINEPIXMAP,
+								marker, GPOINTER_TO_INT (*xpm));
 		marker++;
 	}
 }
@@ -306,32 +307,16 @@ on_reload_dialog_response (GtkWidget *dlg, gint res, TextEditor *te)
 		text_editor_load_file (te);
 	}
 	gtk_widget_destroy (dlg);
+	te->file_modified_widget = NULL;
+	DEBUG_PRINT ("File modified dialog responded");
 }
 
-static void
-on_text_editor_uri_changed (GnomeVFSMonitorHandle *handle,
-							const gchar *monitor_uri,
-							const gchar *info_uri,
-							GnomeVFSMonitorEventType event_type,
-							gpointer user_data)
+static gboolean
+on_text_editor_uri_changed_prompt (TextEditor *te)
 {
 	GtkWidget *dlg;
 	GtkWidget *parent;
 	gchar *buff;
-	TextEditor *te = TEXT_EDITOR (user_data);
-	
-	DEBUG_PRINT ("File changed!!!");
-	
-	if (!(event_type == GNOME_VFS_MONITOR_EVENT_CHANGED ||
-		  event_type == GNOME_VFS_MONITOR_EVENT_CREATED))
-		return;
-	
-	if (!anjuta_util_diff(te->uri, ianjuta_editor_get_text(IANJUTA_EDITOR(te),
-														   0, -1, NULL)))
-		return;
-	
-	if (strcmp (monitor_uri, info_uri) != 0)
-		return;
 	
 	buff =
 		g_strdup_printf (_
@@ -364,6 +349,50 @@ on_text_editor_uri_changed (GnomeVFSMonitorHandle *handle,
 					  G_CALLBACK (gtk_widget_destroy),
 					  dlg);
 	gtk_widget_show (dlg);
+	
+	te->file_modified_widget = dlg;
+
+	return FALSE;
+}
+
+static void
+on_text_editor_uri_changed (GnomeVFSMonitorHandle *handle,
+							const gchar *monitor_uri,
+							const gchar *info_uri,
+							GnomeVFSMonitorEventType event_type,
+							gpointer user_data)
+{
+	TextEditor *te = TEXT_EDITOR (user_data);
+	
+	DEBUG_PRINT ("File changed!!!");
+	
+	if (!(event_type == GNOME_VFS_MONITOR_EVENT_CHANGED ||
+		  event_type == GNOME_VFS_MONITOR_EVENT_CREATED))
+		return;
+	
+	if (!anjuta_util_diff (te->uri, te->last_saved_content))
+	{
+		/* The file content is same. Remove any previous prompt for reload */
+		if (te->file_modified_widget)
+			gtk_widget_destroy (te->file_modified_widget);
+		te->file_modified_widget = NULL;
+		return;
+	}
+	
+	if (strcmp (monitor_uri, info_uri) != 0)
+		return;
+	
+	/* If the file modified dialog is already shown, don't bother showing it
+	 * again.
+	 */
+	if (te->file_modified_widget)
+		return;
+	
+	/* Set up 1 sec timer */
+	if (te->file_modified_timer > 0)
+ 		g_source_remove (te->file_modified_timer);
+	te->file_modified_timer = g_timeout_add (1000,
+							(GSourceFunc)on_text_editor_uri_changed_prompt, te);
 }
 
 static void
@@ -456,6 +485,11 @@ void
 text_editor_dispose (GObject *obj)
 {
 	TextEditor *te = TEXT_EDITOR (obj);
+	if (te->file_modified_timer > 0)
+	{
+		g_source_remove (te->file_modified_timer);
+		te->file_modified_timer = 0;
+	}
 	if (te->monitor)
 	{
 		text_editor_update_monitor (te, TRUE);
@@ -466,7 +500,6 @@ text_editor_dispose (GObject *obj)
 		g_object_unref (te->popup_menu);
 		te->popup_menu = NULL;
 	}
-	
 	if (te->views)
 	{
 		GtkWidget *scintilla;
@@ -509,14 +542,11 @@ void
 text_editor_finalize (GObject *obj)
 {
 	TextEditor *te = TEXT_EDITOR (obj);
-	if (te->filename)
-		g_free (te->filename);
-	if (te->uri)
-		g_free (te->uri);
-	if (te->encoding)
-		g_free (te->encoding);
-	if (te->force_hilite)
-		g_free (te->force_hilite);
+	g_free (te->filename);
+	g_free (te->uri);
+	g_free (te->encoding);
+	g_free (te->force_hilite);
+	g_free (te->last_saved_content);
 	
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (G_OBJECT(te)));
 }
@@ -583,7 +613,7 @@ text_editor_hilite_one (TextEditor * te, AnEditorID editor_id,
 	else
 	{
 		aneditor_command (editor_id, ANE_SETHILITE, (guint) "plain.txt", 0);
-	}
+	} 
 }
 
 void
@@ -1283,7 +1313,7 @@ load_from_file (TextEditor *te, gchar *uri, gchar **err)
 	GnomeVFSResult result;
 	GnomeVFSFileInfo info;
 	GnomeVFSFileSize nchars;
-
+	gchar *file_content;
 	gchar *buffer;
 	gint dos_filter, editor_mode;
 
@@ -1318,8 +1348,13 @@ load_from_file (TextEditor *te, gchar *uri, gchar **err)
 		*err = g_strdup (_("Error while reading from file"));
 		return FALSE;
 	}
+	
+	file_content = g_strdup (buffer);
 
-	if (info.size != nchars) DEBUG_PRINT ("File size and loaded size not matching");
+	if (info.size != nchars)
+	{
+		DEBUG_PRINT ("File size and loaded size not matching");
+	}
 	dos_filter = 
 		anjuta_preferences_get_int (ANJUTA_PREFERENCES (te->preferences),
 									DOS_EOL_CHECK);
@@ -1351,6 +1386,7 @@ load_from_file (TextEditor *te, gchar *uri, gchar **err)
 			{
 				/* bail out */
 				g_free (buffer);
+				g_free (file_content);
 				*err = g_strdup (_("The file does not look like a text file or the file encoding is not supported."
 								   " Please check if the encoding of file is in the supported encodings list."
 								   " If not, add it from the preferences."));
@@ -1370,6 +1406,11 @@ load_from_file (TextEditor *te, gchar *uri, gchar **err)
 							nchars, (long) buffer);
 	
 	g_free (buffer);
+	
+	/* Save the buffer as last saved content */
+	g_free (te->last_saved_content);
+	te->last_saved_content = file_content;
+	
 	gnome_vfs_close(vfs_read);
 	return TRUE;
 }
@@ -1482,15 +1523,18 @@ save_to_file (TextEditor *te, gchar * uri)
 		if (editor_mode == SC_EOL_CRLF && dos_filter)
 		{
 			DEBUG_PRINT ("Filtering Extrageneous DOS characters in dos mode [Unix => Dos]");
-			size = save_filtered_in_dos_mode(vfs_write, data, size);
+			size = save_filtered_in_dos_mode (vfs_write, data, size);
 		}
 		else
 		{
 			result = gnome_vfs_write(vfs_write, data, size, &nchars);
 		}
-		g_free (data);
 	}
 	
+	/* Set last content saved to data */
+	g_free (te->last_saved_content);
+	te->last_saved_content = data;
+	
 	if (result == GNOME_VFS_OK)
 		result = gnome_vfs_close(vfs_write);
 	else
@@ -1509,7 +1553,9 @@ text_editor_load_file (TextEditor * te)
 	if (IS_SCINTILLA (te->scintilla) == FALSE)
 		return FALSE;
 	anjuta_status (te->status, _("Loading file..."), 5); 
+	
 	text_editor_freeze (te);
+	
 	// te->modified_time = time (NULL);
 	text_editor_update_monitor (te, FALSE);
 	if (load_from_file (te, te->uri, &err) == FALSE)
@@ -2091,6 +2137,12 @@ itext_editor_set_use_spaces (IAnjutaEditor *editor, gboolean use_spaces, GError
 							SCI_SETUSETABS, !use_spaces, 0);
 }
 
+static void
+itext_editor_set_auto_indent (IAnjutaEditor *editor, gboolean auto_indent, GError **e)
+{
+  text_editor_command (TEXT_EDITOR(editor), ANE_SETINDENTMAINTAIN, auto_indent, 0);
+}
+
 static void
 itext_editor_goto_line (IAnjutaEditor *editor, gint lineno, GError **e)
 {
@@ -2331,6 +2383,7 @@ itext_editor_iface_init (IAnjutaEditorIface *iface)
 	iface->set_tabsize = itext_editor_set_tab_size;
 	iface->get_use_spaces = itext_editor_get_use_spaces;
 	iface->set_use_spaces = itext_editor_set_use_spaces;
+	iface->set_auto_indent = itext_editor_set_auto_indent;	
 	iface->goto_line = itext_editor_goto_line;
 	iface->goto_position = itext_editor_goto_position;
 	iface->get_text = itext_editor_get_text;
@@ -2600,18 +2653,21 @@ marker_ianjuta_to_editor (IAnjutaMarkableMarker marker)
 	gint mark;
 	switch (marker)
 	{
-		case IANJUTA_MARKABLE_BASIC:
+		case IANJUTA_MARKABLE_LINEMARKER:
 			mark = TEXT_EDITOR_LINEMARKER;
 			break;
-		case IANJUTA_MARKABLE_LIGHT:
+		case IANJUTA_MARKABLE_BOOKMARK:
 			mark = TEXT_EDITOR_BOOKMARK;
 			break;
-		case IANJUTA_MARKABLE_ATTENTIVE:
+		case IANJUTA_MARKABLE_BREAKPOINT_DISABLED:
 			mark = TEXT_EDITOR_BREAKPOINT_DISABLED;
 			break;
-		case IANJUTA_MARKABLE_INTENSE:
+		case IANJUTA_MARKABLE_BREAKPOINT_ENABLED:
 			mark = TEXT_EDITOR_BREAKPOINT_ENABLED;
 			break;
+		case IANJUTA_MARKABLE_PROGRAM_COUNTER:
+			mark = TEXT_EDITOR_PROGRAM_COUNTER;
+			break;
 		default:
 			mark = TEXT_EDITOR_LINEMARKER;
 	}
