@@ -151,13 +151,14 @@ const static GdbMessageCode GdbErrorMessage[] =
 	IANJUTA_DEBUGGER_UNABLE_TO_CREATE_VARIABLE},
 	{"Cannot access memory at address ",
 	IANJUTA_DEBUGGER_UNABLE_TO_ACCESS_MEMORY},
+	{"No source file named  ",
+	IANJUTA_DEBUGGER_UNABLE_TO_OPEN_FILE},
 	{NULL, 0}};
 
 static guint
 gdb_match_error(const gchar *message)
 {
-	GdbMessageCode* msg;
-	guint code;
+	const GdbMessageCode* msg;
 
 	for (msg = GdbErrorMessage; msg->msg != NULL; msg++)
 	{
@@ -531,11 +532,7 @@ debugger_queue_command (Debugger *debugger, const gchar *cmd,
 		dc->keep_result = keep_result;
 	}
 	debugger->priv->cmd_queqe = g_list_append (debugger->priv->cmd_queqe, dc);
-	if (!debugger->priv->debugger_is_busy &&
-		g_list_length (debugger->priv->cmd_queqe) >= 1)
-	{
-		debugger_queue_execute_command (debugger);
-	}
+	debugger_queue_execute_command (debugger);
 }
 
 static void
@@ -581,10 +578,14 @@ debugger_queue_execute_command (Debugger *debugger)
 {
 	DEBUG_PRINT ("In function: debugger_queue_execute_command()");
 
-	debugger_clear_buffers (debugger);
-	if (debugger_queue_set_next_command (debugger))
-//	if (strlen (debugger->priv->current_cmd.cmd))
+	if (!debugger->priv->debugger_is_busy &&
+		!debugger->priv->starting &&
+		g_list_length (debugger->priv->cmd_queqe) >= 1)
+	{
+		debugger_clear_buffers (debugger);
+		if (debugger_queue_set_next_command (debugger))
 		debugger_execute_command (debugger, debugger->priv->current_cmd.cmd);
+	}
 }
 
 static void
@@ -655,7 +656,8 @@ debugger_load_core (Debugger *debugger, const gchar *core)
 
 gboolean
 debugger_start (Debugger *debugger, const GList *search_dirs,
-				const gchar *prog, gboolean is_libtool_prog)
+				const gchar *prog, gboolean is_libtool_prog,
+				gboolean terminal)
 {
 	gchar *command_str, *dir, *tmp, *text, *msg;
 	gchar *exec_dir;
@@ -663,9 +665,23 @@ debugger_start (Debugger *debugger, const GList *search_dirs,
 	const GList *node;
 	AnjutaLauncher *launcher;
 	GList *dir_list = NULL;
+	gchar *term = NULL;
 	
 	DEBUG_PRINT ("In function: debugger_start(%s) libtool %d", prog == NULL ? "(null)" : prog, is_libtool_prog);
 
+	/* Without a terminal, the output of the debugged program
+	 * are lost */
+	if (terminal)
+	{
+		term = debugger_start_terminal (debugger);
+		if (term)
+		{
+			tmp = g_strconcat (" -tty=", term, NULL);
+			g_free(term);
+			term = tmp;
+		}
+	}
+	
 	if (anjuta_util_prog_is_installed ("gdb", TRUE) == FALSE)
 		return FALSE;
 
@@ -744,15 +760,15 @@ debugger_start (Debugger *debugger, const GList *search_dirs,
 			chdir (exec_dir);
 		if (is_libtool_prog == FALSE)
 		{
-			command_str = g_strdup_printf (GDB_PATH " -f -n -i=mi2 %s -cd=%s "
-										   "-x %s/gdb.init %s", dir, tmp,
+			command_str = g_strdup_printf (GDB_PATH " -f -n -i=mi2 %s %s "
+										   "-x %s/gdb.init %s", dir, term == NULL ? "" : term,
 										   PACKAGE_DATA_DIR, prog);
 		}
 		else
 		{
 			command_str = g_strdup_printf ("libtool --mode=execute " GDB_PATH
-										   " -f -n -i=mi2 %s -cd=%s "
-										   "-x %s/gdb.init %s", dir, tmp,
+										   " -f -n -i=mi2 %s %s "
+										   "-x %s/gdb.init %s", dir, term == NULL ? "" : term,
 										   PACKAGE_DATA_DIR, prog);
 		}
 	}
@@ -760,19 +776,20 @@ debugger_start (Debugger *debugger, const GList *search_dirs,
 	{
 		if (is_libtool_prog == FALSE)
 		{
-			command_str = g_strdup_printf (GDB_PATH " -f -n -i=mi2 %s "
-										   "-x %s/gdb.init ",
+			command_str = g_strdup_printf (GDB_PATH " -f -n -i=mi2 %s %s "
+										   "-x %s/gdb.init ", term == NULL ? "" : term,
 										   dir, PACKAGE_DATA_DIR);
 		}
 		else
 		{
 			command_str = g_strdup_printf ("libtool --mode=execute " GDB_PATH
-										   " -f -n -i=mi2 %s -x "
+										   " -f -n -i=mi2 %s %s -x "
 										   "%s/gdb.init ",
-										   dir, PACKAGE_DATA_DIR);
+										   dir, term == NULL ? "" : term, PACKAGE_DATA_DIR);
 		}
 	}
 	g_free (dir);
+	g_free (term);
 	debugger->priv->starting = TRUE;
 	debugger->priv->terminating = FALSE;
 	debugger->priv->loading = prog != NULL ? TRUE : FALSE;
@@ -780,6 +797,7 @@ debugger_start (Debugger *debugger, const GList *search_dirs,
 
 	/* Prepare for launch. */
 	launcher = debugger->priv->launcher;
+	anjuta_launcher_set_terminate_on_exit (launcher, TRUE);
 	g_signal_connect (G_OBJECT (launcher), "child-exited",
 					  G_CALLBACK (on_gdb_terminated), debugger);
 	ret = anjuta_launcher_execute (launcher, command_str,
@@ -914,60 +932,47 @@ static void
 debugger_process_frame (Debugger *debugger, const GDBMIValue *val)
 {
 	const GDBMIValue *file, *line, *frame, *addr, *fullname;
-	const gchar *file_str, *line_str, *addr_str, *fullname_str;
-	
-	if (!val)
-		return;
-	
-	fullname_str = file_str = line_str = addr_str = NULL;
+	const gchar *file_str = NULL;
+	guint line_num = 0;
+	gulong addr_num = 0;
 	
 	g_return_if_fail (val != NULL);
 	
-	file = gdbmi_value_hash_lookup (val, "file");
-	line = gdbmi_value_hash_lookup (val, "line");
 	frame = gdbmi_value_hash_lookup (val, "frame");
-	addr = gdbmi_value_hash_lookup (val, "addr");
-	fullname = gdbmi_value_hash_lookup (val, "fullname");
-	
-	if (file && line)
+	if (frame)
 	{
-		file_str = gdbmi_value_literal_get (file);
-		line_str = gdbmi_value_literal_get (line);
-
-		if (fullname)
-		       	fullname_str = gdbmi_value_literal_get (fullname);
-		
-		if (addr)
-			addr_str = gdbmi_value_literal_get (addr);
-		
-		if (file_str && line_str)
-		{
-			debugger_change_location (debugger, fullname_str ? fullname_str : file_str,
-									  atoi(line_str), addr_str);
-		}
-	}
-	else if (frame)
-	{
-		file = gdbmi_value_hash_lookup (frame, "file");
-		line = gdbmi_value_hash_lookup (frame, "line");
 		fullname = gdbmi_value_hash_lookup (frame, "fullname");
-		
+		fullname = NULL;
 		if (fullname)
-		       	fullname_str = gdbmi_value_literal_get (fullname);
-		
-		if (addr)
-			addr_str = gdbmi_value_literal_get (addr);
-	
-		if (file && line)
 		{
-			file_str = gdbmi_value_literal_get (file);
-			line_str = gdbmi_value_literal_get (line);
-			if (file_str && line_str)
+			file_str = gdbmi_value_literal_get (fullname);
+			if (*file_str == '\0') file_str = NULL;
+		}
+		else
+		{
+			file = gdbmi_value_hash_lookup (frame, "file");
+			if (file)
 			{
-				debugger_change_location (debugger, fullname_str ? fullname_str : file_str,
-										  atoi(line_str), addr_str);
+				file_str = gdbmi_value_literal_get (file);
+				if (*file_str == '\0') file_str = NULL;
 			}
 		}
+
+		if (file_str != NULL)
+		{
+			line = gdbmi_value_hash_lookup (frame, "line");
+			if (line)
+			{
+				line_num = strtoul (gdbmi_value_literal_get (line), NULL, 0);
+			}
+		}
+
+		addr = gdbmi_value_hash_lookup (frame, "addr");
+		if (addr)
+		{
+			addr_num = strtoul (gdbmi_value_literal_get (addr), NULL, 0);
+		}
+		debugger_change_location (debugger, file_str, line_num, addr_num);
 	}
 }
 
@@ -1017,7 +1022,7 @@ debugger_parse_output (Debugger *debugger)
 		gdb_util_parse_error_line (&(line[2]), &filename, &lineno);
 		if (filename)
 		{
-			debugger_change_location (debugger, filename, lineno, NULL);
+			debugger_change_location (debugger, filename, lineno, 0);
 			g_free (filename);
 		}
 	}
@@ -1072,7 +1077,7 @@ debugger_parse_stopped (Debugger *debugger)
 	{
 		gboolean program_exited = FALSE;		
 		GDBMIValue *val;
-		
+
 		/* Check if program has exited */
 		val = gdbmi_value_parse (line);
 		if (val)
@@ -1228,12 +1233,7 @@ debugger_parse_prompt (Debugger *debugger)
 	}
 	
 	debugger->priv->debugger_is_busy--;
-
-	if (!debugger->priv->debugger_is_busy &&
-		g_list_length (debugger->priv->cmd_queqe) >= 1)
-	{
-		debugger_queue_execute_command (debugger);	/* Next command. Go. */
-	}
+	debugger_queue_execute_command (debugger);	/* Next command. Go. */
 	debugger_emit_status (debugger);
 	
 	#if 0
@@ -1444,7 +1444,7 @@ on_gdb_terminated (AnjutaLauncher *launcher,
 	if (!debugger->priv->terminating)
 	{
 		anjuta_util_dialog_error (debugger->priv->parent_win,
-		_("gdb terminated unexpectedly with error code %d\n"), status);
+		_("gdb terminated unexpectedly with status %d\n"), status);
 	}
 	debugger_stop_terminal (debugger);
 	debugger->priv->prog_is_running = FALSE;
@@ -1597,12 +1597,11 @@ debugger_set_output_callback (Debugger *debugger, IAnjutaDebuggerOutputCallback
 
 void
 debugger_change_location (Debugger *debugger, const gchar *file,
-						  gint line, const gchar *address)
+						  gint line, guint address)
 {
 	gchar *src_path;
 	
-	g_return_if_fail (file != NULL);
-	if (*file != G_DIR_SEPARATOR)
+	if ((file != NULL) && (*file != G_DIR_SEPARATOR))
 	{
 		src_path = debugger_get_source_path (debugger, file);
 		g_signal_emit_by_name (debugger->priv->instance, "location-changed", src_path, line, address);
@@ -1834,9 +1833,9 @@ debugger_info_program_finish (Debugger *debugger, const GDBMIValue *mi_results,
 }
 
 void
-debugger_start_program (Debugger *debugger, const gchar* args, gboolean terminal)
+debugger_start_program (Debugger *debugger, const gchar* args)
 {
-	gchar *term, *cmd;
+	gchar *cmd;
 
 	DEBUG_PRINT ("In function: debugger_start_program()");
 
@@ -1852,19 +1851,8 @@ debugger_start_program (Debugger *debugger, const gchar* args, gboolean terminal
 		g_free (cmd);
 	}
 
-	term = debugger_start_terminal (debugger);
-	if (term)
-	{
-		cmd = g_strconcat ("tty ", term, NULL);
-		debugger_queue_command (debugger, cmd, FALSE, FALSE, NULL, NULL, NULL);
-		debugger_queue_command (debugger, "-exec-run", FALSE, FALSE, NULL, NULL, NULL);
-		g_free (cmd);
-		g_free (term);
-	}
-	else
-	{
-		debugger_queue_command (debugger, "-exec-run", FALSE, FALSE, NULL, NULL, NULL);
-	}
+	debugger_queue_command (debugger, "-exec-run", FALSE, FALSE, NULL, NULL, NULL);
+	
 	/* Get pid of program on next stop */
 	debugger_queue_command (debugger, "info program", FALSE, FALSE, debugger_info_program_finish, NULL, NULL);
 	debugger->priv->post_execution_flag = DEBUGGER_NONE;
@@ -1883,7 +1871,7 @@ debugger_attach_process_finish (Debugger *debugger, const GDBMIValue *mi_results
 	}
 	debugger->priv->prog_is_attached = TRUE;
 	debugger->priv->prog_is_running = TRUE;
-	g_signal_emit_by_name (debugger->priv->instance, "program-exited");
+	debugger_emit_status (debugger);
 }
 
 static void
@@ -2231,15 +2219,13 @@ debugger_add_breakpoint_finish (Debugger *debugger, const GDBMIValue *mi_results
 
 	bp.enable = IANJUTA_DEBUGGER_UNDEFINED;
 	bp.keep = IANJUTA_DEBUGGER_UNDEFINED;
-	if (mi_results == NULL)
+	
+	if ((error == NULL) || (mi_results == NULL))
 	{
-		if (strncmp((const gchar *)cli_results->data,"&No source file named ", 22) == 0)
-		{
-			/* Breakpoint cannot be set, dynamic library not loaded ? */
-		}
-		/* Useful for enable that doesn't return anything */
+		/* Call callback in all case (useful for enable that doesn't return
+ 		* anything */
 		if (callback != NULL)
-			callback (NULL, user_data, NULL);
+			callback (NULL, user_data, error);
 	}
 	else
 	{
@@ -2340,12 +2326,13 @@ debugger_add_breakpoint_finish (Debugger *debugger, const GDBMIValue *mi_results
 		{       
 			value = gdbmi_value_literal_get (literal);
 		}
-
+		
 		/* Call callback in all case (useful for enable that doesn't return
-	 	* anything */
+ 		* anything */
 		if (callback != NULL)
-			callback (&bp, user_data, NULL);
+			callback (NULL, user_data, error);
 	}
+	
 }
 	
 void
@@ -2776,7 +2763,7 @@ debugger_read_memory_finish (Debugger *debugger, const GDBMIValue *mi_results, c
 	const gchar *value;
 	gchar *data;
 	gchar *ptr;
-	gchar *address;
+	guint address;
 	guint len;
 	guint i;
 	IAnjutaDebuggerCallback callback = debugger->priv->current_cmd.callback;
@@ -2793,7 +2780,7 @@ debugger_read_memory_finish (Debugger *debugger, const GDBMIValue *mi_results, c
 		memset (data + len, 0, len);
 
 		literal = gdbmi_value_hash_lookup (mi_results, "addr");
-		address = (char *)strtoul (gdbmi_value_literal_get (literal), NULL, 0);
+		address = strtoul (gdbmi_value_literal_get (literal), NULL, 0);
 	
 		ptr = data;
 		size = 0;
@@ -2925,7 +2912,6 @@ void
 debugger_disassemble (Debugger *debugger, guint address, guint length, IAnjutaDebuggerCallback callback, gpointer user_data)
 {
 	gchar *buff;
-	guint end;
 	
 	DEBUG_PRINT ("In function: debugger_disassemble()");
 
