@@ -25,7 +25,7 @@
  * list of people on the anjuta Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: anjuta-document-saver.c 2714 2007-01-04 20:41:01Z naba $
+ * $Id: anjuta-document-saver.c 2769 2007-01-26 13:21:38Z jhs $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1248,8 +1248,8 @@ anjuta_document_saver_save (AnjutaDocumentSaver     *saver,
 	if ((flags & ANJUTA_DOCUMENT_SAVE_PRESERVE_BACKUP) != 0)
 		saver->priv->keep_backup = FALSE;
 	else
-		/* FIXME */
-		saver->priv->keep_backup = FALSE;
+		/* FIXME: This should be configurable */
+		saver->priv->keep_backup =TRUE;
 
 	/* TODO: add support for configurable backup dir */
 	saver->priv->backups_in_curr_dir = TRUE;
