@@ -277,19 +277,54 @@ static void on_document_saving(AnjutaDocument    *document,
 	anjuta_status_progress_tick(status, NULL, _("Saving..."));
 }
 
+static gboolean save_if_modified(AnjutaDocument* doc, GtkWindow* parent)
+{
+	GtkWidget* dialog = gtk_message_dialog_new(parent,
+    	GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, 
+    	_("The file %s was modified by another application. Save it anyway?"), anjuta_document_get_uri_for_display(doc));
+    int result = gtk_dialog_run(GTK_DIALOG(dialog));
+    gtk_widget_destroy(dialog);
+    switch (result)
+    {
+    	case GTK_RESPONSE_YES:
+    	{
+    		return TRUE;
+   		}
+   		default:
+   			return FALSE;
+   	}
+}
+
 /* Called when document is saved completly */
 static void on_document_saved(AnjutaDocument* doc, GError* err, Sourceview* sv)
 {
 	if (err)
 	{
-		anjuta_util_dialog_error(NULL,
-			 "Could not save file: %s", err->message);
+		switch(err->code)
+		{
+			case ANJUTA_DOCUMENT_ERROR_EXTERNALLY_MODIFIED:
+			{
+    			if (save_if_modified(doc, GTK_WINDOW(sv->priv->plugin->shell)))
+    			{
+    				anjuta_document_save(doc, ANJUTA_DOCUMENT_SAVE_IGNORE_MTIME);
+    			}
+    			break;
+			}
+			default:
+			{
+				anjuta_util_dialog_error(NULL,
+				 		"Could not save file %s: %s",anjuta_document_get_uri_for_display(doc),  err->message);
+				break;
+			}
+		}
+	}
+	else
+	{
+		gtk_text_buffer_set_modified(GTK_TEXT_BUFFER(doc), FALSE);
+		g_signal_emit_by_name(G_OBJECT(sv), "save_point", TRUE);
+		sourceview_add_monitor(sv);
+		sv->priv->saving = FALSE;
 	}
-	gtk_text_buffer_set_modified(GTK_TEXT_BUFFER(doc), FALSE);
-	g_signal_emit_by_name(G_OBJECT(sv), "save_point",
-						  TRUE);
-	sourceview_add_monitor(sv);
-	sv->priv->saving = FALSE;
 }
 
 static void 
@@ -332,18 +367,18 @@ sourceview_finalize(GObject *object)
 
 /* Sync with IANJUTA_MARKABLE_MARKER  */
 
-#define MARKER_PIXMAP_BASIC "marker-basic.png"
-#define MARKER_PIXMAP_LIGHT "marker-light.png"
-#define MARKER_PIXMAP_ATTENTIVE "marker-attentive.png"
-#define MARKER_PIXMAP_INTENSE "marker-intense.png"
+#define MARKER_PIXMAP_LINEMARKER "linemarker.png"
+#define MARKER_PIXMAP_PROGRAM_COUNTER "program-counter.png"
+#define MARKER_PIXMAP_BREAKPOINT_DISABLED "breakpoint-disabled.png"
+#define MARKER_PIXMAP_BREAKPOINT_ENABLED "breakpoint-enabled.png"
 
 #define MARKER_PIXMAP_BOOKMARK "bookmark.png"
 
-#define MARKER_NONE "sv-mark-none"
-#define MARKER_BASIC "sv-mark-basic"
-#define MARKER_LIGHT "sv-mark-light"
-#define MARKER_ATTENTIVE "sv-mark-attentive"
-#define MARKER_INTENSE "sv-mark-intense"
+#define MARKER_NONE "sv-none"
+#define MARKER_LINEMARKER "sv-linemarker"
+#define MARKER_PROGRAM_COUNTER "sv-program-counter"
+#define MARKER_BREAKPOINT_DISABLED "sv-breakpoint-disabled"
+#define MARKER_BREAKPOINT_ENABLED "sv-breakpoint-enabled"
 
 #define MARKER_BOOKMARK "sv-bookmark"
 
@@ -360,36 +395,36 @@ static void sourceview_create_markers(Sourceview* sv)
 	GtkSourceView* view = 	GTK_SOURCE_VIEW(sv->priv->view);
 
 	
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BASIC, NULL)))
-	{
-		gtk_source_view_set_marker_pixbuf (view, 
-			MARKER_BASIC, pixbuf);
-		g_object_unref (pixbuf);
-	}
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_LIGHT, NULL)))
-	{
-		gtk_source_view_set_marker_pixbuf (view, 
-			MARKER_LIGHT, pixbuf);
-		g_object_unref (pixbuf);
-	}
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_ATTENTIVE, NULL)))
-	{
-		gtk_source_view_set_marker_pixbuf (view, 
-			MARKER_ATTENTIVE, pixbuf);
-		g_object_unref (pixbuf);
-	}
-	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_INTENSE, NULL)))
-	{
-		gtk_source_view_set_marker_pixbuf (view, 
-			MARKER_INTENSE, pixbuf);
-		g_object_unref (pixbuf);
-	}
 	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BOOKMARK, NULL)))
 	{
 		gtk_source_view_set_marker_pixbuf (view, 
 			MARKER_BOOKMARK, pixbuf);
 		g_object_unref (pixbuf);
 	}
+	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BREAKPOINT_DISABLED, NULL)))
+	{
+		gtk_source_view_set_marker_pixbuf (view, 
+			MARKER_BREAKPOINT_DISABLED, pixbuf);
+		g_object_unref (pixbuf);
+	}
+	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_BREAKPOINT_ENABLED, NULL)))
+	{
+		gtk_source_view_set_marker_pixbuf (view, 
+			MARKER_BREAKPOINT_ENABLED, pixbuf);
+		g_object_unref (pixbuf);
+	}
+	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_PROGRAM_COUNTER, NULL)))
+	{
+		gtk_source_view_set_marker_pixbuf (view, 
+			MARKER_PROGRAM_COUNTER, pixbuf);
+		g_object_unref (pixbuf);
+	}
+	if ((pixbuf = gdk_pixbuf_new_from_file (PACKAGE_PIXMAPS_DIR"/"MARKER_PIXMAP_LINEMARKER, NULL)))
+	{
+		gtk_source_view_set_marker_pixbuf (view, 
+			MARKER_LINEMARKER, pixbuf);
+		g_object_unref (pixbuf);
+	}
 }
 
 /* Create tags for highlighting */
@@ -437,8 +472,6 @@ sourceview_new(const gchar* uri, const gchar* filename, AnjutaPlugin* plugin)
 					 
 	/* Create View instance */
 	sv->priv->view = ANJUTA_VIEW(anjuta_view_new(sv->priv->document));
-	/* Fix #388727 */
-	g_object_set(G_OBJECT(sv->priv->view), "indent_on_tab", TRUE, NULL);
 	g_signal_connect_after(G_OBJECT(sv->priv->view), "char_added",
 					G_CALLBACK(on_document_char_added), sv);
 	gtk_source_view_set_smart_home_end(GTK_SOURCE_VIEW(sv->priv->view), FALSE);
@@ -512,7 +545,7 @@ ifile_savable_save (IAnjutaFileSavable* file, GError** e)
 	Sourceview* sv = ANJUTA_SOURCEVIEW(file);
 	sourceview_remove_monitor(sv);
 					 
-	anjuta_document_save(sv->priv->document, ANJUTA_DOCUMENT_SAVE_IGNORE_BACKUP);
+	anjuta_document_save(sv->priv->document, 0);
 }
 
 /* Save file as */
@@ -523,8 +556,7 @@ ifile_savable_save_as (IAnjutaFileSavable* file, const gchar *uri, GError** e)
 	sourceview_remove_monitor(sv);
 	/* TODO: Set correct encoding */
 	anjuta_document_save_as(sv->priv->document, 
-							uri, anjuta_encoding_get_current(),
-							ANJUTA_DOCUMENT_SAVE_IGNORE_BACKUP);
+							uri, anjuta_encoding_get_current(), 0);
 	if (sv->priv->filename)
 	{
 		g_free(sv->priv->filename);
@@ -599,6 +631,15 @@ ieditor_set_use_spaces (IAnjutaEditor *editor, gboolean use_spaces, GError **e)
 	gtk_source_view_set_insert_spaces_instead_of_tabs(GTK_SOURCE_VIEW(sv->priv->view), use_spaces);
 }
 
+static void
+ieditor_set_auto_indent (IAnjutaEditor *editor, gboolean auto_indent, GError **e)
+{
+	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
+	DEBUG_PRINT("Setting auto-indent to %d", auto_indent);
+	gtk_source_view_set_auto_indent(GTK_SOURCE_VIEW(sv->priv->view), auto_indent);
+}
+
+
 /* Scroll to line */
 static void ieditor_goto_line(IAnjutaEditor *editor, gint line, GError **e)
 {
@@ -650,7 +691,6 @@ static gchar* ieditor_get_text(IAnjutaEditor* editor, gint position,
 									&start_iter, &end_iter, TRUE);
 }
 
-#if 0
 static IAnjutaEditorAttribute*
 ieditor_get_attributes(IAnjutaEditor* editor, 
 					   gint positon, gint length, GError **e)
@@ -665,7 +705,6 @@ ieditor_get_attributes(IAnjutaEditor* editor,
 	}
 	return attribs;
 }
-#endif
 
 /* Get cursor position */
 static gint ieditor_get_position(IAnjutaEditor* editor, GError **e)
@@ -923,10 +962,11 @@ ieditor_iface_init (IAnjutaEditorIface *iface)
 	iface->set_tabsize = ieditor_set_tab_size;
 	iface->get_use_spaces = ieditor_get_use_spaces;
 	iface->set_use_spaces = ieditor_set_use_spaces;
+  iface->set_auto_indent = ieditor_set_auto_indent;
 	iface->goto_line = ieditor_goto_line;
 	iface->goto_position = ieditor_goto_position;
 	iface->get_text = ieditor_get_text;
-//	iface->get_attributes = ieditor_get_attributes;
+  iface->get_attributes = ieditor_get_attributes;
 	iface->get_position = ieditor_get_position;
 	iface->get_lineno = ieditor_get_lineno;
 	iface->get_length = ieditor_get_length;
@@ -1264,23 +1304,23 @@ imark_mark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
 									 &iter, location  - 1);
 	switch (marker)
 	{
-		case IANJUTA_MARKABLE_NONE:
-			name = MARKER_NONE;
+		case IANJUTA_MARKABLE_LINEMARKER:
+			name = MARKER_LINEMARKER;
 			break;
-		case IANJUTA_MARKABLE_BASIC:
-			name = MARKER_BASIC;
+		case IANJUTA_MARKABLE_PROGRAM_COUNTER:
+			name = MARKER_PROGRAM_COUNTER;
 			break;
-		case IANJUTA_MARKABLE_LIGHT:
-			name = MARKER_LIGHT;
+		case IANJUTA_MARKABLE_BOOKMARK:
+			name = MARKER_BOOKMARK;
 			break;
-		case IANJUTA_MARKABLE_INTENSE:
-			name = MARKER_INTENSE;
+		case IANJUTA_MARKABLE_BREAKPOINT_DISABLED:
+			name = MARKER_BREAKPOINT_DISABLED;
 			break;
-		case IANJUTA_MARKABLE_ATTENTIVE:
-			name = MARKER_ATTENTIVE;
+		case IANJUTA_MARKABLE_BREAKPOINT_ENABLED:
+			name = MARKER_BREAKPOINT_ENABLED;
 			break;
 		default:
-			DEBUG_PRINT("Unkonown marker type: %d!", marker);
+			DEBUG_PRINT("Unknown marker type: %d!", marker);
 			name = MARKER_NONE;
 	}
 		
@@ -1398,7 +1438,12 @@ iindic_clear (IAnjutaIndicable *indic, GError **e)
 	gtk_text_buffer_remove_tag_by_name (GTK_TEXT_BUFFER(sv->priv->document),
 	                                     IMPORTANT_INDIC,
 	                                     &start, &end);
-	// Remove warning_indic, critical_indic
+	gtk_text_buffer_remove_tag_by_name (GTK_TEXT_BUFFER(sv->priv->document),
+	                                     WARNING_INDIC,
+	                                     &start, &end);
+	gtk_text_buffer_remove_tag_by_name (GTK_TEXT_BUFFER(sv->priv->document),
+	                                     CRITICAL_INDIC,
+	                                     &start, &end);
 }
 
 static void
