@@ -37,7 +37,7 @@
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
-#include <libanjuta/plugins.h>
+#include <libanjuta/anjuta-plugin-manager.h>
 #include <libanjuta/anjuta-debug.h>
 
 #include "anjuta-app.h"
@@ -148,16 +148,27 @@ on_toolbar_view_toggled (GtkCheckMenuItem *menuitem, GtkWidget *widget)
 	{
 		if (!dock_item)
 		{
+			static gint count;
+			gchar *unique_name = g_strdup_printf ("%s-%d", name, count);
+			
+			/* gnome_app_add_docked() does not allow adding a widget using
+			 * a previously used name (even if the previous widget has
+			 * has be destroyed. Hence a unique_name is used by using a 
+			 * static counter */
+			DEBUG_PRINT ("Adding dock item %s", unique_name);
+			
 			/* Widget not yet added to the dock. Add it */
 			gnome_app_add_docked (GNOME_APP (app), widget,
-								  name,
+								  unique_name,
 								  BONOBO_DOCK_ITEM_BEH_NEVER_VERTICAL |
 								  BONOBO_DOCK_ITEM_BEH_NEVER_FLOATING,
 								  BONOBO_DOCK_TOP, band, 0, 0);
 		
 			dock_item = gnome_app_get_dock_item_by_name (GNOME_APP (app),
-														 name);
+														 unique_name);
 			g_object_set_data (G_OBJECT(widget), "dock_item", dock_item);
+			g_free (unique_name);
+			count++;
 		}
 		gtk_widget_show (GTK_WIDGET (dock_item));
 		gtk_widget_show (GTK_BIN (dock_item)->child);
@@ -169,6 +180,13 @@ on_toolbar_view_toggled (GtkCheckMenuItem *menuitem, GtkWidget *widget)
 	}
 }
 
+static void
+on_merge_widget_destroy (GtkWidget *merge_widget, GtkWidget *menuitem)
+{
+	toolbars = g_list_remove (toolbars, merge_widget);
+	gtk_widget_destroy (menuitem);
+}
+
 static void
 on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 					 GtkWidget *ui_container)
@@ -221,6 +239,13 @@ on_add_merge_widget (GtkUIManager *merge, GtkWidget *widget,
 		g_signal_connect (G_OBJECT (menuitem), "toggled",
 						  G_CALLBACK (on_toolbar_view_toggled), widget);
 		g_object_set_data(G_OBJECT(widget), "menuitem", menuitem);
+		
+		/* When the toolbar is destroyed make sure corresponding menuitem is
+		 * also destroyed */
+		g_signal_connect (widget, "destroy",
+						  G_CALLBACK (on_merge_widget_destroy),
+						  menuitem);
+		
 		toolbars = g_list_append(toolbars, widget);
 
 		/* Show/hide toolbar */
@@ -266,7 +291,6 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 		}
 		node = g_list_next(node);
 	}
-
 	
 	/* Save geometry */
 	state = gdk_window_get_state (GTK_WIDGET (app)->window);
@@ -383,6 +407,10 @@ anjuta_app_dispose (GObject *widget)
 		g_object_unref (app->layout_manager);
 		app->layout_manager = NULL;
 	}
+	if (app->plugin_manager) {
+		g_object_unref (G_OBJECT (app->plugin_manager));
+		app->plugin_manager = NULL;
+	}
 	if (app->status) {
 		g_object_unref (G_OBJECT (app->status));
 		app->status = NULL;
@@ -398,7 +426,7 @@ anjuta_app_finalize (GObject *widget)
 	g_return_if_fail (ANJUTA_IS_APP (widget));
 	
 	app = ANJUTA_APP (widget);
-
+	
 	gtk_widget_destroy (GTK_WIDGET (app->ui));
 	gtk_widget_destroy (GTK_WIDGET (app->preferences));
 	
@@ -415,7 +443,7 @@ anjuta_app_instance_init (AnjutaApp *app)
 	GtkWidget *dockbar;
 	GtkAccelGroup *accel_group;
 	GtkAction* action;
-	
+	GList *plugins_dirs = NULL;
 	GdkGeometry size_hints = {
     	100, 100, 0, 0, 100, 100, 1, 1, 0.0, 0.0, GDK_GRAVITY_NORTH_WEST
   	};
@@ -490,6 +518,13 @@ anjuta_app_instance_init (AnjutaApp *app)
 					  app);
 	g_object_add_weak_pointer (G_OBJECT (app->ui), (gpointer*)&app->ui);
 	
+	/* Plugin Manager */
+	plugins_dirs = g_list_prepend (plugins_dirs, PACKAGE_PLUGIN_DIR);
+	app->plugin_manager = anjuta_plugin_manager_new (G_OBJECT (app),
+													 app->status,
+													 plugins_dirs);
+	g_list_free (plugins_dirs);
+	
 	/* Register actions */
 	anjuta_ui_add_action_group_entries (app->ui, "ActionGroupFile", _("File"),
 										menu_entries_file,
@@ -1053,7 +1088,8 @@ anjuta_app_get_object  (AnjutaShell *shell, const char *iface_name,
 {
 	g_return_val_if_fail (ANJUTA_IS_APP (shell), NULL);
 	g_return_val_if_fail (iface_name != NULL, NULL);
-	return anjuta_plugins_get_plugin (shell, iface_name);
+	return anjuta_plugin_manager_get_plugin (ANJUTA_APP (shell)->plugin_manager,
+											 iface_name);
 }
 
 static AnjutaStatus*
@@ -1077,6 +1113,13 @@ anjuta_app_get_preferences  (AnjutaShell *shell, GError **error)
 	return ANJUTA_APP (shell)->preferences;
 }
 
+static AnjutaPluginManager *
+anjuta_app_get_plugin_manager  (AnjutaShell *shell, GError **error)
+{
+	g_return_val_if_fail (ANJUTA_IS_APP (shell), NULL);
+	return ANJUTA_APP (shell)->plugin_manager;
+}
+
 static void
 anjuta_shell_iface_init (AnjutaShellIface *iface)
 {
@@ -1090,6 +1133,7 @@ anjuta_shell_iface_init (AnjutaShellIface *iface)
 	iface->get_status = anjuta_app_get_status;
 	iface->get_ui = anjuta_app_get_ui;
 	iface->get_preferences = anjuta_app_get_preferences;
+	iface->get_plugin_manager = anjuta_app_get_plugin_manager;
 }
 
 ANJUTA_TYPE_BEGIN(AnjutaApp, anjuta_app, GNOME_TYPE_APP);
